==> megadata-0.0.76.tar.gz: megadata-0.0.76/README.md <==
# MEGADATA

lib and tools for 'megadata'

# PHILOSOPHY

"remove if worthy"

# INSTALL

python -m pip install -U megadata

# TODO

## more server/client shell for databases or servers ;)

```
python -m megadata *args **kwargs

e.g.

## start quick web on 127.0.0.1:80
-m megadata svrweb 80

## start quick nng on tcp://127.0.0.1:3366
-m megadata svrweb 3366
```

# NO WARRANT WARNING

## Use at your own risk !

This software package is intended for data research purposes only. It is provided as-is, without any warranties or guarantees of any kind. 

**Risk Disclosure:**
This software package is not intended for use in production systems. It may contain bugs, errors, or vulnerabilities that could result in unexpected behavior or compromise the security and integrity of your systems. By using this software package, you acknowledge and assume all risks associated with its use. The authors and contributors of this software package shall not be liable for any damages or losses arising from its use.

We strongly recommend not using this software package in any critical or production systems. It is solely for educational, experimental, and non-commercial purposes.

Please use this software package responsibly and at your own risk.

# 風險自負！

本軟體包僅供數據研究目的使用。它是按原樣提供的，沒有任何形式的保證或擔保。

## 風險披露：

本軟體包不適用於生產系統。它可能包含漏洞、錯誤或脆弱性，這些可能導致意外行為或威脅到您系統的安全性和完整性。使用本軟體包，您承認並承擔與其使用相關的所有風險。本軟體包的作者和貢獻者不承擔因其使用而產生的任何損害或損失。

我們強烈建議不在任何關鍵或生產系統中使用此軟體包。它僅供教育、實驗和非商業目的使用。

請負責任地使用本軟件包，並自行承擔風險

# SUPPORT

* 請我喝杯咖啡 [BUY-ME-A-COFFE 25 CNY](https://buy.stripe.com/4gw8xu1Ij61CbCw4gm) 
* 加我VX(wanjochan)討論技術問題

<!--
<script async
  src="https://js.stripe.com/v3/buy-button.js">
</script>

<stripe-buy-button
  buy-button-id="buy_btn_1O1LWzAZeDyeb7mKWtFSiHs8"
  publishable-key="pk_live_51MtUANAZeDyeb7mKtPVXLIE7iHlW4JQ6tdlOfMDOftxjOFLZKwBy8eBo39kaCUbGhrw8FXNz5rb3Xhyr78KP40cN00KwFFgzYL"
>
</stripe-buy-button>
-->

==> megadata-0.0.77.tar.gz: megadata-0.0.77/README.md <==
# MEGADATA

lib and tools for 'megadata' and 'megashare'

# PHILOSOPHY

"remove if worthy"

# INSTALL

python -m pip install -U megadata

# TODO

## more server/client quick tools for databases or servers ;)

```
python -m megadata *args **kwargs

e.g.

## start quick web on 127.0.0.1:80
python -m megadata svrweb 80

## start quick nng on tcp://127.0.0.1:3366
python -m megadata svrweb 3366
```

# NO WARRANT WARNING

## Use at your own risk !

This software package is intended for data research purposes only. It is provided as-is, without any warranties or guarantees of any kind. 

**Risk Disclosure:**
This software package is not intended for use in production systems. It may contain bugs, errors, or vulnerabilities that could result in unexpected behavior or compromise the security and integrity of your systems. By using this software package, you acknowledge and assume all risks associated with its use. The authors and contributors of this software package shall not be liable for any damages or losses arising from its use.

We strongly recommend not using this software package in any critical or production systems. It is solely for educational, experimental, and non-commercial purposes.

Please use this software package responsibly and at your own risk.

# 風險自負！

本軟體包僅供數據研究目的使用。它是按原樣提供的，沒有任何形式的保證或擔保。

## 風險披露：

本軟體包不適用於生產系統。它可能包含漏洞、錯誤或脆弱性，這些可能導致意外行為或威脅到您系統的安全性和完整性。使用本軟體包，您承認並承擔與其使用相關的所有風險。本軟體包的作者和貢獻者不承擔因其使用而產生的任何損害或損失。

我們強烈建議不在任何關鍵或生產系統中使用此軟體包。它僅供教育、實驗和非商業目的使用。

請負責任地使用本軟件包，並自行承擔風險

# SUPPORT

* 請我喝杯咖啡 [BUY-ME-A-COFFE 25 CNY](https://buy.stripe.com/4gw8xu1Ij61CbCw4gm) 
<!--
<script async src="https://js.stripe.com/v3/buy-button.js"> </script>

<stripe-buy-button buy-button-id="buy_btn_1O1LWzAZeDyeb7mKWtFSiHs8"
  publishable-key="pk_live_51MtUANAZeDyeb7mKtPVXLIE7iHlW4JQ6tdlOfMDOftxjOFLZKwBy8eBo39kaCUbGhrw8FXNz5rb3Xhyr78KP40cN00KwFFgzYL"
></stripe-buy-button>
-->
